<?php
function calculate_discount($order_id) {
    error_log("Calculating discount for order ID: $order_id");

    // گرفتن اطلاعات سفارش
    $order = wc_get_order($order_id);
    if (!$order) {
        error_log("Order not found for ID: $order_id");
        return 0;
    }

    // متغیر برای ذخیره مجموع تخفیف
    $total_discount = 0;

    // مرور آیتم‌های سفارش
    foreach ($order->get_items() as $item) {
        $product = $item->get_product();
        if (!$product) {
            error_log("Product not found for item in order ID: $order_id");
            continue;
        }

        // گرفتن قیمت اصلی و قیمت ویژه محصول
        $regular_price = $product->get_regular_price();  // قیمت اصلی
        $sale_price = $product->get_sale_price();  // قیمت ویژه (تخفیف خورده)

        // اگر قیمت ویژه وجود داشته باشد
        if ($sale_price) {
            // محاسبه درصد تخفیف برای هر محصول
            $discount = ($regular_price - $sale_price) * 100 / $regular_price;
            $total_discount += $discount * $item->get_quantity();  // اضافه کردن تخفیف به مجموع کل
        }
    }

    error_log("Total discount for order ID $order_id: $total_discount");
    return round($total_discount); // بازگشت تخفیف کل در قالب درصد
}

function send_order_to_accounting_api($order_id) {
    error_log("Preparing to send order ID: $order_id to accounting API");

    // دریافت توکن از تنظیمات
    $token = get_option('accounting_api_token');
    if (!$token) {
        error_log("API token not found in settings");
        return new WP_Error('missing_token', 'توکن موجود نیست');
    }

    // گرفتن اطلاعات سفارش
    $order = wc_get_order($order_id);
    if (!$order) {
        error_log("Invalid order ID: $order_id");
        return new WP_Error('invalid_order', 'سفارش معتبر نمی‌باشد');
    }

    // محاسبه تخفیف
    $discount = calculate_discount($order_id);

    // آماده‌سازی داده‌ها برای ارسال
    $order_items = $order->get_items();
    $rows = [];

    foreach ($order_items as $item) {
        $product = $item->get_product();
        if (!$product) {
            error_log("Product not found for item in order ID: $order_id");
            continue;
        }

        $sku = $product->get_sku(); // دریافت SKU محصول
        $quantity = $item->get_quantity(); // تعداد محصول
        $total = $item->get_total(); // قیمت کل
        $warehouse = get_option('accounting_api_warehouse_id'); // دریافت کد انبار از متا دیتا

        // اضافه کردن هر آیتم به آرایه rows
        $rows[] = [
            'ware' => $sku,
            'count' => $quantity,
            'fee' => $total,
            'warehouse' => $warehouse,
        ];
    }

    $data = [
        'discount' => $discount, // مقدار تخفیف محاسبه‌شده
        'rows' => $rows,
    ];

    error_log("Data prepared for API: " . print_r($data, true));

    // ارسال درخواست به API
    $url = 'https://api.app.sobhan.net/store/factor';
    $response = wp_remote_post($url, [
        'headers' => [
            'Authorization' => 'Token ' . $token,
            'Content-Type' => 'application/json',
        ],
        'body' => json_encode($data),
        'timeout' => 15,
    ]);

    // بررسی نتیجه درخواست
    if (is_wp_error($response)) {
        error_log("API request error: " . $response->get_error_message());
        return new WP_Error('api_request_error', 'خطا در ارسال داده‌ها به API: ' . $response->get_error_message());
    }

    $response_code = wp_remote_retrieve_response_code($response);
    $response_body = wp_remote_retrieve_body($response);

    if ($response_code !== 200) {
        error_log("API error with status code $response_code: $response_body");
        return new WP_Error('api_error', 'خطا در پاسخ API با کد وضعیت ' . $response_code . ': ' . $response_body);
    }

    // پردازش پاسخ در صورت موفقیت
    $body = json_decode($response_body, true);
    error_log("API response: " . print_r($body, true));

    // به‌روزرسانی انبار
    $warehouse = get_option('accounting_api_warehouse_id'); // دریافت کد انبار
    error_log("Updating stock for warehouse: $warehouse");
    accounting_api_update_stock($warehouse);

    return $body;
}
?>